package SLA4;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

import com.metamaxim.modelscope.callbacks.Behaviour;
import com.metamaxim.modelscope.callbacks.Instance;

public class IndicatorPeriod extends Indicator {
	
	/**
	 * Return the calculated indicator value.
	 * 
	 * @return
	 */
	public Object getIndicatorValue()
	{
		Instance slaMonitor = this.getInstance("SLA Contract Monitor");
		
		Instance slo = this.getInstance("SLO");
		String period = slo.getString("Norm Period", "Period Value");
		
		String measurementAttributeName = this.getString("Measurement Attribute");
		
		
		return sum(slaMonitor, period, measurementAttributeName);
	}
	
	/**
	 * Returns the sum of the measurement attribute values for the indicated period
	 * of a specific SLA Contract Monitor.
	 * 
	 * @param slaMonitor
	 * @param period
	 * @param measurementAttributeName
	 * @return
	 */
	protected int sum(Instance slaMonitor, String period, String measurementAttributeName)
	{
		int totalValue = 0;		
		for (Instance measurement: this.getMeasurementsInPeriod(slaMonitor, period))
		{
			totalValue += measurement.getInteger(measurementAttributeName);
		}

		return totalValue;		
	}
	
	/**
	 * Returns the count of the measurements available within the period for the SLA Contract.
	 * 
	 * @param slaMonitor
	 * @param period
	 * @return
	 */
	protected int count(Instance slaMonitor, String period)
	{
		return this.getMeasurementsInPeriod(slaMonitor, period).size();
	}
	
	/**
	 * Returns measurements that fall into the indicated period for a specific SLA Contract Monitor.
	 * 
	 * @param slaMonitor
	 * @param period
	 * @return
	 */
	protected List<Instance> getMeasurementsInPeriod(Instance slaMonitor, String period)
	{
		long periodStart = System.currentTimeMillis() - new Period(period).getTime();
		SimpleDateFormat sdf = new SimpleDateFormat("dd-MM-yyy HH:mm:ss.sss");
		
		List <Instance>measurements = new ArrayList<Instance>();
		
		for (Instance measurement: slaMonitor.selectByRef("RequestReply Measurement", "SLA Contract Monitor"))
		{
			if (periodStart <= AddRequestReplyMeasurement.getTimeMillis( measurement.getString("Time Stamp") ) )
			{
				measurements.add(measurement);
			}
		}
		
		return measurements;
	}

}
