package SLA4;

import com.metamaxim.modelscope.callbacks.Behaviour;
import com.metamaxim.modelscope.callbacks.Instance;

public class ViolationDetector extends Behaviour {
	
	/**
	 * Returns the violation condition in a textual way.
	 * 
	 * @return
	 */
	public String getCaption()
	{
		return getViolation() ? "Violated" : "Unviolated";
	}
	
	/**
	 * Returns true is the actual value violates the criteria, i.e. is not in line.
	 * 
	 * @return
	 */
	public boolean getViolation()
	{
		//
		//	If the actual value is in line with the criteria, then there is no violation.
		//	Hence the inverted boolean of the criteria assertion is returned,
		//	as the violation indication.
		//
		return !assertCriteria();
	}
	
	/**
	 * Returns true if the actual value is in line with the criteria
	 * 
	 * @return
	 */
	protected boolean assertCriteria()
	{
		Instance slo = this.getInstance("SLO");
		String normCriteria = slo.getString("Norm Criteria");
		int normValue = slo.getInteger("Norm Value");
		int indicatorValue = this.getInteger("Indicator Value");
		
		switch (normCriteria)
		{
		case "<":
			return indicatorValue < normValue;
		case "<=":
			return indicatorValue <= normValue;
		case "=":
		case "==":
			return indicatorValue == normValue;
		case "!=":
		case "<>":
			return indicatorValue != normValue;
		case ">":
			return indicatorValue > normValue;
		case ">=":
			return indicatorValue >= normValue;
		}
		
		throw new RuntimeException("Unkown violation criteria: \"" + normCriteria + "\"");
	}

}
