package SLA4;

import com.metamaxim.modelscope.callbacks.Behaviour;
import com.metamaxim.modelscope.callbacks.Instance;

public class ViolationDetectorTime extends Behaviour {
	
	/**
	 * Returns the violation condition in a textual way.
	 * 
	 * @return
	 */
	public String getCaption()
	{
		return getViolation() ? "Violated" : "Unviolated";
	}
	
	/**
	 * Returns true is the actual value violates the criteria, i.e. is not in line.
	 * 
	 * @return
	 */
	public boolean getViolation()
	{
		//
		//	If the actual value is in line with the criteria, then there is no violation.
		//	Hence the inverted boolean of the criteria assertion is returned,
		//	as the violation indication.
		//
		return !assertCriteria();
	}
	
	/**
	 * Returns true if the actual value is in line with the criteria
	 * 
	 * @return
	 */
	protected boolean assertCriteria()
	{
		Instance slo = this.getInstance("SLO");
		String normCriteria = slo.getString("Norm Criteria");
		String normValue = slo.getString("Norm Value");
		String indicatorValue = this.getString("Indicator Value");
		
		if (indicatorValue == null || indicatorValue.length() == 0)
			return true;
		
		long normTime = new Period(normValue).getTime();
		long indicatorTime = new Period(indicatorValue).getTime();
		
		switch (normCriteria)
		{
		case "<":
			return indicatorTime < normTime;
		case "<=":
			return indicatorTime <= normTime;
		case "=":
		case "==":
			return indicatorTime == normTime;
		case "!=":
		case "<>":
			return indicatorTime != normTime;
		case ">":
			return indicatorTime > normTime;
		case ">=":
			return indicatorTime >= normTime;
		}
		
		throw new RuntimeException("Unkown violation criteria: \"" + normCriteria + "\"");
	}

}
